/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009-2012 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */

package org.ow2.jonas.admin.osgiconsole.command {
import com.adobe.cairngorm.commands.ICommand;
import com.adobe.cairngorm.control.CairngormEvent;
import com.adobe.cairngorm.control.CairngormEventDispatcher;

import mx.collections.ArrayCollection;
import mx.controls.Alert;
import mx.rpc.IResponder;
import mx.rpc.events.ResultEvent;

import org.ow2.jonas.admin.osgiconsole.business.BundleDelegate;

import org.ow2.jonas.admin.osgiconsole.event.BundleInfoUpdateEvent;
import org.ow2.jonas.admin.osgiconsole.model.OSGiConsoleModelLocator;
import org.ow2.jonas.admin.osgiconsole.vo.BundleInfoResultVO;

public class BundleInfoUpdateCommand implements ICommand,IResponder {
    private var model:OSGiConsoleModelLocator = OSGiConsole.getInstance().getModel();
    private var dispatcher:CairngormEventDispatcher = OSGiConsole.getInstance().getDispatcher();

    public function BundleInfoUpdateCommand() {
    }

    public function execute(event:CairngormEvent):void {
        try {
            var delegate:BundleDelegate = model.bundleDelegate;
            delegate.responder = this;
            delegate.updateBundleList();
        } catch (e:Error) {
            Alert.show("error " + e.message);
            trace("An error occurred: " + e.message);
        }
    }

    public function result(event:Object):void {
        var resultEvent:ResultEvent = event as ResultEvent;
        var bundleInfoResult:BundleInfoResultVO = resultEvent.result as BundleInfoResultVO;
        var changed:Boolean = bundleInfoResult.changed;
        [ArrayElementType(BundleInfoVO)]
        var bundles:ArrayCollection = model.bundles;
        if (changed == true) {
            bundles.removeAll();
            bundles.addAll(bundleInfoResult.bundlelist);
        }
        dispatcher.dispatchEvent(new BundleInfoUpdateEvent(BundleInfoUpdateEvent.EVENT_UPDATE_BUNDLE_LIST));
    }

    public function fault(info:Object):void {
        Alert.show(info.result);
    }
}
}